@@ -24,6 +24,5 @@ protected:
     void closeEvent(QCloseEvent *event) override;
 
 private:
-    MainWidget *mMain;
+    MainWidget *const mMain;
 };
-
